# This package contains generic base classes for APIClients

from .APIClientBase import APIClientBase
from .LoginSession import LoginSession, NullLoginSession
from ._version import get_versions
__version__ = get_versions()['version']
del get_versions



# Base class for login sessions

class LoginSession():
  def injectHeaders(self, headers):
    raise Exception("LoginSession.injectHeaders Not Implemented")

  # Return true if sucessful and falst if not
  #  true will prompt the APIClient to resend the request
  def refresh(self):
    raise Exception("LoginSession.refresh Not Implemented")

class NullLoginSession():
  def injectHeaders(self, headers):
    return

  def refresh(self):
    return False #no session to refresh so no need to retry call


from setuptools import setup
import versioneer

#Dependancy lists maintained here and in tox.ini
sp_install_requires = [
  'requests==2.20.1',
  'pytz==2019.3',
  'python-dateutil==2.8.1'
]
sp_tests_require = [
  'nose==1.3.7',
  'python_Testing_Utilities==0.1.5'
]

all_require = sp_install_requires + sp_tests_require

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(name='PythonAPIClientBase',
      version=versioneer.get_version(),
      cmdclass=versioneer.get_cmdclass(),
      description='Base classes for APIClients',
      long_description=long_description,
      long_description_content_type="text/markdown",
      url='https://github.com/rmetcalf9/PythonAPIClientBase',
      author='Robert Metcalf',
      author_email='rmetcalf9@googlemail.com',
      license='MIT',
      packages=['PythonAPIClientBase'],
      zip_safe=False,
      install_requires=sp_install_requires,
      tests_require=sp_tests_require,
      include_package_data=True)
